summaryrefslogtreecommitdiffstats
path: root/src/compiler
diff options
context:
space:
mode:
authorDave Airlie <[email protected]>2016-06-09 07:50:43 +1000
committerDave Airlie <[email protected]>2016-06-09 09:17:24 +1000
commit15896a470b2b56cefc2a00ce458fd784ed42cee9 (patch)
treeb80c0b035fd782eb5a6515e3269c2cec7a450ea0 /src/compiler
parent45c901f7a3a22898426a0c5dd4b39587a2432dd7 (diff)
glsl/types: rename is_dual_slot_double to is_dual_slot_64bit.
In the future int64 support will have the same requirements. Reviewed-by: Ilia Mirkin <[email protected]> Signed-off-by: Dave Airlie <[email protected]>
Diffstat (limited to 'src/compiler')
-rw-r--r--src/compiler/glsl/ir_set_program_inouts.cpp4
-rw-r--r--src/compiler/glsl/linker.cpp4
-rw-r--r--src/compiler/glsl_types.h6
3 files changed, 7 insertions, 7 deletions
diff --git a/src/compiler/glsl/ir_set_program_inouts.cpp b/src/compiler/glsl/ir_set_program_inouts.cpp
index 183b13b82e3..1f9971dffc7 100644
--- a/src/compiler/glsl/ir_set_program_inouts.cpp
+++ b/src/compiler/glsl/ir_set_program_inouts.cpp
@@ -119,7 +119,7 @@ mark(struct gl_program *prog, ir_variable *var, int offset, int len,
/* double inputs read is only for vertex inputs */
if (stage == MESA_SHADER_VERTEX &&
- var->type->without_array()->is_dual_slot_double())
+ var->type->without_array()->is_dual_slot())
prog->DoubleInputsRead |= bitfield;
if (stage == MESA_SHADER_FRAGMENT) {
@@ -306,7 +306,7 @@ ir_set_program_inouts_visitor::try_mark_partial_variable(ir_variable *var,
/* double element width for double types that takes two slots */
if (this->shader_stage != MESA_SHADER_VERTEX ||
var->data.mode != ir_var_shader_in) {
- if (type->without_array()->is_dual_slot_double())
+ if (type->without_array()->is_dual_slot())
elem_width *= 2;
}
diff --git a/src/compiler/glsl/linker.cpp b/src/compiler/glsl/linker.cpp
index 9e6559005d7..4ddd46e3a80 100644
--- a/src/compiler/glsl/linker.cpp
+++ b/src/compiler/glsl/linker.cpp
@@ -2863,7 +2863,7 @@ assign_attribute_or_color_locations(gl_shader_program *prog,
* issue (3) of the GL_ARB_vertex_attrib_64bit behavior, this
* is optional behavior, but it seems preferable.
*/
- if (var->type->without_array()->is_dual_slot_double())
+ if (var->type->without_array()->is_dual_slot())
double_storage_locations |= (use_mask << attr);
}
@@ -2940,7 +2940,7 @@ assign_attribute_or_color_locations(gl_shader_program *prog,
to_assign[i].var->data.is_unmatched_generic_inout = 0;
used_locations |= (use_mask << location);
- if (to_assign[i].var->type->without_array()->is_dual_slot_double())
+ if (to_assign[i].var->type->without_array()->is_dual_slot())
double_storage_locations |= (use_mask << location);
}
diff --git a/src/compiler/glsl_types.h b/src/compiler/glsl_types.h
index 21021324786..c3a01854fc2 100644
--- a/src/compiler/glsl_types.h
+++ b/src/compiler/glsl_types.h
@@ -495,11 +495,11 @@ struct glsl_type {
}
/**
* Query whether a double takes two slots.
*/
- bool is_dual_slot_double() const
+ bool is_dual_slot() const
{
- return base_type == GLSL_TYPE_DOUBLE && vector_elements > 2;
+ return is_64bit() && vector_elements > 2;
}
/**
@@ -495,11 +495,11 @@ struct glsl_type {
}
/**
- * Query whether a double takes two slots.
+ * Query whether a 64-bit type takes two slots.
*/